@@ -18,9 +18,9 @@
 
 from typing import Any, List, Optional
 
-from gvm.errors import RequiredArgument, InvalidArgumentType
+from gvm.errors import InvalidArgument, RequiredArgument, InvalidArgumentType
 from gvm.protocols.gmpv208.entities.severity import Severity, SeverityLevel
-from gvm.utils import add_filter, to_comma_list, to_bool
+from gvm.utils import add_filter, check_port, to_comma_list, to_bool
 from gvm.xml import XmlCommand
 
 
@@ -32,7 +32,7 @@ class OverridesMixin:
         *,
         days_active: Optional[int] = None,
         hosts: Optional[List[str]] = None,
-        port: Optional[int] = None,
+        port: Optional[str] = None,
         result_id: Optional[str] = None,
         severity: Optional[Severity] = None,
         new_severity: Optional[Severity] = None,
@@ -47,7 +47,8 @@ class OverridesMixin:
             nvt_id: OID of the nvt to which override applies
             days_active: Days override will be active. -1 on always, 0 off
             hosts: A list of host addresses
-            port: Port to which the override applies
+            port: Port to which the override applies, needs to be a string
+                  in the form {number}/{protocol}
             result_id: UUID of a result to which override applies
             severity: Severity to which override applies
             new_severity: New severity for result
@@ -81,15 +82,20 @@ class OverridesMixin:
             cmd.add_element("hosts", to_comma_list(hosts))
 
         if port:
-            cmd.add_element("port", str(port))
+            if check_port(port):
+                cmd.add_element("port", str(port))
+            else:
+                raise InvalidArgument(
+                    function=self.create_override.__name__, argument='port'
+                )
 
         if result_id:
             cmd.add_element("result", attrs={"id": result_id})
 
-        if severity:
+        if severity is not None:
             cmd.add_element("severity", str(severity))
 
-        if new_severity:
+        if new_severity is not None:
             cmd.add_element("new_severity", str(new_severity))
 
         if task_id:
@@ -215,7 +221,7 @@ class OverridesMixin:
         *,
         days_active: Optional[int] = None,
         hosts: Optional[List[str]] = None,
-        port: Optional[int] = None,
+        port: Optional[str] = None,
         result_id: Optional[str] = None,
         severity: Optional[Severity] = None,
         new_severity: Optional[Severity] = None,
@@ -231,7 +237,8 @@ class OverridesMixin:
             days_active: Days override will be active. -1 on always,
                 0 off.
             hosts: A list of host addresses
-            port: Port to which override applies.
+            port: Port to which the override applies, needs to be a string
+                  in the form {number}/{protocol}
             result_id: Result to which override applies.
             severity: Severity to which override applies.
             new_severity: New severity score for result.
@@ -264,15 +271,20 @@ class OverridesMixin:
             cmd.add_element("hosts", to_comma_list(hosts))
 
         if port:
-            cmd.add_element("port", str(port))
+            if check_port(port):
+                cmd.add_element("port", str(port))
+            else:
+                raise InvalidArgument(
+                    function=self.modify_override.__name__, argument='port'
+                )
 
         if result_id:
             cmd.add_element("result", attrs={"id": result_id})
 
-        if severity:
+        if severity is not None:
             cmd.add_element("severity", str(severity))
 
-        if new_severity:
+        if new_severity is not None:
             cmd.add_element("new_severity", str(new_severity))
 
         if task_id:
