@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2020-2021 Greenbone Networks GmbH
+# Copyright (C) 2020-2022 Greenbone Networks GmbH
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -17,6 +17,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from io import StringIO
+import os
 import unittest
 from unittest.mock import patch, Mock
 from pathlib import Path
@@ -103,6 +104,38 @@ class SSHConnectionTestCase(unittest.TestCase):
         ):
             ssh_connection.connect()
 
+    def test_connect_denied_known_hosts_file(self):
+        if os.path.exists(self.known_hosts_file):
+            os.chmod(self.known_hosts_file, 0000)
+
+        ssh_connection = SSHConnection(
+            hostname='0.0.0.1', known_hosts_file=self.known_hosts_file
+        )
+        with self.assertRaises(
+            GvmError,
+            msg=(
+                "Could'nt establish a connection to fetch the remote "
+                "server key: [Errno 65] No route to host"
+            ),
+        ):
+            ssh_connection.connect()
+
+    def test_connect_no_known_hosts_file(self):
+        if os.path.exists(self.known_hosts_file):
+            os.remove(self.known_hosts_file)
+
+        ssh_connection = SSHConnection(
+            hostname='0.0.0.1', known_hosts_file=self.known_hosts_file
+        )
+        with self.assertRaises(
+            GvmError,
+            msg=(
+                "Could'nt establish a connection to fetch the remote "
+                "server key: [Errno 65] No route to host"
+            ),
+        ):
+            ssh_connection.connect()
+
     @patch('builtins.input')
     def test_connect_adding_and_save_hostkey(self, input_mock):
 
