@@ -18,7 +18,7 @@
 
 from decimal import Decimal
 
-from gvm.errors import RequiredArgument
+from gvm.errors import InvalidArgument, RequiredArgument
 
 from gvm.protocols.gmpv214 import SeverityLevel
 
@@ -80,21 +80,12 @@ class GmpModifyNoteTestMixin:
         )
 
     def test_modify_note_with_port(self):
-        self.gmp.modify_note(note_id='n1', text='foo', port='123')
+        self.gmp.modify_note(note_id='n1', text='foo', port='123/tcp')
 
         self.connection.send.has_been_called_with(
             '<modify_note note_id="n1">'
             '<text>foo</text>'
-            '<port>123</port>'
-            '</modify_note>'
-        )
-
-        self.gmp.modify_note(note_id='n1', text='foo', port=123)
-
-        self.connection.send.has_been_called_with(
-            '<modify_note note_id="n1">'
-            '<text>foo</text>'
-            '<port>123</port>'
+            '<port>123/tcp</port>'
             '</modify_note>'
         )
 
@@ -173,3 +164,10 @@ class GmpModifyNoteTestMixin:
         self.connection.send.has_been_called_with(
             '<modify_note note_id="n1">' '<text>foo</text>' '</modify_note>'
         )
+
+    def test_modify_note_with_invalid_port(self):
+        with self.assertRaises(InvalidArgument):
+            self.gmp.modify_note(note_id='o1', text='foo', port='123')
+
+        with self.assertRaises(InvalidArgument):
+            self.gmp.modify_note(note_id='o1', text='foo', port='tcp/123')
